# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.jsonable_encoder import encode_path_param
from ...core.parse_error import ParsingError
from ...core.pydantic_utilities import parse_obj_as
from ...core.request_options import RequestOptions
from ...errors.bad_request_error import BadRequestError
from ...errors.forbidden_error import ForbiddenError
from ...errors.not_found_error import NotFoundError
from ...errors.too_many_requests_error import TooManyRequestsError
from ...errors.unauthorized_error import UnauthorizedError
from ...types.get_custom_texts_by_language_response_content import GetCustomTextsByLanguageResponseContent
from ...types.prompt_group_name_enum import PromptGroupNameEnum
from ...types.prompt_language_enum import PromptLanguageEnum
from ...types.sets_custom_texts_by_language_request_content import SetsCustomTextsByLanguageRequestContent
from pydantic import ValidationError

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawCustomTextClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self,
        prompt: PromptGroupNameEnum,
        language: PromptLanguageEnum,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetCustomTextsByLanguageResponseContent]:
        """
        Retrieve custom text for a specific prompt and language.

        Parameters
        ----------
        prompt : PromptGroupNameEnum
            Name of the prompt.

        language : PromptLanguageEnum
            Language to update.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetCustomTextsByLanguageResponseContent]
            Prompt dictionaries successfully retrieved.
        """
        _response = self._client_wrapper.httpx_client.request(
            f"prompts/{encode_path_param(prompt)}/custom-text/{encode_path_param(language)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetCustomTextsByLanguageResponseContent,
                    parse_obj_as(
                        type_=GetCustomTextsByLanguageResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def set(
        self,
        prompt: PromptGroupNameEnum,
        language: PromptLanguageEnum,
        *,
        request: SetsCustomTextsByLanguageRequestContent,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        Set custom text for a specific prompt. Existing texts will be overwritten.

        Parameters
        ----------
        prompt : PromptGroupNameEnum
            Name of the prompt.

        language : PromptLanguageEnum
            Language to update.

        request : SetsCustomTextsByLanguageRequestContent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"prompts/{encode_path_param(prompt)}/custom-text/{encode_path_param(language)}",
            method="PUT",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawCustomTextClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self,
        prompt: PromptGroupNameEnum,
        language: PromptLanguageEnum,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetCustomTextsByLanguageResponseContent]:
        """
        Retrieve custom text for a specific prompt and language.

        Parameters
        ----------
        prompt : PromptGroupNameEnum
            Name of the prompt.

        language : PromptLanguageEnum
            Language to update.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetCustomTextsByLanguageResponseContent]
            Prompt dictionaries successfully retrieved.
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"prompts/{encode_path_param(prompt)}/custom-text/{encode_path_param(language)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetCustomTextsByLanguageResponseContent,
                    parse_obj_as(
                        type_=GetCustomTextsByLanguageResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def set(
        self,
        prompt: PromptGroupNameEnum,
        language: PromptLanguageEnum,
        *,
        request: SetsCustomTextsByLanguageRequestContent,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        Set custom text for a specific prompt. Existing texts will be overwritten.

        Parameters
        ----------
        prompt : PromptGroupNameEnum
            Name of the prompt.

        language : PromptLanguageEnum
            Language to update.

        request : SetsCustomTextsByLanguageRequestContent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"prompts/{encode_path_param(prompt)}/custom-text/{encode_path_param(language)}",
            method="PUT",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



from .conftest import get_client, verify_request_count


def test_branding_templates_get_universal_login() -> None:
    """Test getUniversalLogin endpoint with WireMock"""
    test_id = "branding.templates.get_universal_login.0"
    client = get_client(test_id)
    client.branding.templates.get_universal_login()
    verify_request_count(test_id, "GET", "/branding/templates/universal-login", None, 1)


def test_branding_templates_update_universal_login() -> None:
    """Test updateUniversalLogin endpoint with WireMock"""
    test_id = "branding.templates.update_universal_login.0"
    client = get_client(test_id)
    client.branding.templates.update_universal_login(
        request="string",
    )
    verify_request_count(test_id, "PUT", "/branding/templates/universal-login", None, 1)


def test_branding_templates_delete_universal_login() -> None:
    """Test deleteUniversalLogin endpoint with WireMock"""
    test_id = "branding.templates.delete_universal_login.0"
    client = get_client(test_id)
    client.branding.templates.delete_universal_login()
    verify_request_count(test_id, "DELETE", "/branding/templates/universal-login", None, 1)



# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventOrgGroupRoleAssignedObjectGroup1TypeEnum = typing.Union[typing.Literal["organization"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

import typing

SetSelfServiceProfileCustomTextResponseContent = typing.Dict[str, str]
"""
The resulting list of custom text keys and values.
"""



# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.request_options import RequestOptions
from ....types.get_guardian_factor_phone_message_types_response_content import (
    GetGuardianFactorPhoneMessageTypesResponseContent,
)
from ....types.get_guardian_factor_phone_templates_response_content import (
    GetGuardianFactorPhoneTemplatesResponseContent,
)
from ....types.get_guardian_factors_provider_phone_response_content import (
    GetGuardianFactorsProviderPhoneResponseContent,
)
from ....types.get_guardian_factors_provider_phone_twilio_response_content import (
    GetGuardianFactorsProviderPhoneTwilioResponseContent,
)
from ....types.guardian_factor_phone_factor_message_type_enum import GuardianFactorPhoneFactorMessageTypeEnum
from ....types.guardian_factors_provider_sms_provider_enum import GuardianFactorsProviderSmsProviderEnum
from ....types.set_guardian_factor_phone_message_types_response_content import (
    SetGuardianFactorPhoneMessageTypesResponseContent,
)
from ....types.set_guardian_factor_phone_templates_response_content import (
    SetGuardianFactorPhoneTemplatesResponseContent,
)
from ....types.set_guardian_factors_provider_phone_response_content import (
    SetGuardianFactorsProviderPhoneResponseContent,
)
from ....types.set_guardian_factors_provider_phone_twilio_response_content import (
    SetGuardianFactorsProviderPhoneTwilioResponseContent,
)
from .raw_client import AsyncRawPhoneClient, RawPhoneClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class PhoneClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawPhoneClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawPhoneClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawPhoneClient
        """
        return self._raw_client

    def get_message_types(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetGuardianFactorPhoneMessageTypesResponseContent:
        """
        Retrieve list of <a href="https://auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa">phone-type MFA factors</a> (i.e., sms and voice) that are enabled for your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetGuardianFactorPhoneMessageTypesResponseContent
            Returns the enabled phone factors

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.factors.phone.get_message_types()
        """
        _response = self._raw_client.get_message_types(request_options=request_options)
        return _response.data

    def set_message_types(
        self,
        *,
        message_types: typing.Sequence[GuardianFactorPhoneFactorMessageTypeEnum],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetGuardianFactorPhoneMessageTypesResponseContent:
        """
        Replace the list of <a href="https://auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa">phone-type MFA factors</a> (i.e., sms and voice) that are enabled for your tenant.

        Parameters
        ----------
        message_types : typing.Sequence[GuardianFactorPhoneFactorMessageTypeEnum]
            The list of phone factors to enable on the tenant. Can include `sms` and `voice`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianFactorPhoneMessageTypesResponseContent
            Returns selected SMS provider configuration

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.factors.phone.set_message_types(
            message_types=["sms"],
        )
        """
        _response = self._raw_client.set_message_types(message_types=message_types, request_options=request_options)
        return _response.data

    def get_twilio_provider(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetGuardianFactorsProviderPhoneTwilioResponseContent:
        """
        Retrieve configuration details for a Twilio phone provider that has been set up in your tenant. To learn more, review <a href="https://auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa">Configure SMS and Voice Notifications for MFA</a>.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetGuardianFactorsProviderPhoneTwilioResponseContent
            Twilio Phone configuration successfully retrieved.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.factors.phone.get_twilio_provider()
        """
        _response = self._raw_client.get_twilio_provider(request_options=request_options)
        return _response.data

    def set_twilio_provider(
        self,
        *,
        from_: typing.Optional[str] = OMIT,
        messaging_service_sid: typing.Optional[str] = OMIT,
        auth_token: typing.Optional[str] = OMIT,
        sid: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetGuardianFactorsProviderPhoneTwilioResponseContent:
        """
        Update the configuration of a Twilio phone provider that has been set up in your tenant. To learn more, review <a href="https://auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa">Configure SMS and Voice Notifications for MFA</a>.

        Parameters
        ----------
        from_ : typing.Optional[str]
            From number

        messaging_service_sid : typing.Optional[str]
            Copilot SID

        auth_token : typing.Optional[str]
            Twilio Authentication token

        sid : typing.Optional[str]
            Twilio SID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianFactorsProviderPhoneTwilioResponseContent
            Twilio Phone configuration successfully updated.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.factors.phone.set_twilio_provider()
        """
        _response = self._raw_client.set_twilio_provider(
            from_=from_,
            messaging_service_sid=messaging_service_sid,
            auth_token=auth_token,
            sid=sid,
            request_options=request_options,
        )
        return _response.data

    def get_selected_provider(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetGuardianFactorsProviderPhoneResponseContent:
        """
        Retrieve details of the multi-factor authentication phone provider configured for your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetGuardianFactorsProviderPhoneResponseContent
            Returns selected Phone provider configuration

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.factors.phone.get_selected_provider()
        """
        _response = self._raw_client.get_selected_provider(request_options=request_options)
        return _response.data

    def set_provider(
        self,
        *,
        provider: GuardianFactorsProviderSmsProviderEnum,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetGuardianFactorsProviderPhoneResponseContent:
        """
        Parameters
        ----------
        provider : GuardianFactorsProviderSmsProviderEnum

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianFactorsProviderPhoneResponseContent
            Returns selected Phone provider configuration

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.factors.phone.set_provider(
            provider="auth0",
        )
        """
        _response = self._raw_client.set_provider(provider=provider, request_options=request_options)
        return _response.data

    def get_templates(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetGuardianFactorPhoneTemplatesResponseContent:
        """
        Retrieve details of the multi-factor authentication enrollment and verification templates for phone-type factors available in your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetGuardianFactorPhoneTemplatesResponseContent
            Phone enrollment and verification templates successfully retrieved.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.factors.phone.get_templates()
        """
        _response = self._raw_client.get_templates(request_options=request_options)
        return _response.data

    def set_templates(
        self,
        *,
        enrollment_message: str,
        verification_message: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetGuardianFactorPhoneTemplatesResponseContent:
        """
        Customize the messages sent to complete phone enrollment and verification (subscription required).

        Parameters
        ----------
        enrollment_message : str
            Message sent to the user when they are invited to enroll with a phone number.

        verification_message : str
            Message sent to the user when they are prompted to verify their account.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianFactorPhoneTemplatesResponseContent
            Phone enrollment and verification templates successfully updated.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.factors.phone.set_templates(
            enrollment_message="enrollment_message",
            verification_message="verification_message",
        )
        """
        _response = self._raw_client.set_templates(
            enrollment_message=enrollment_message,
            verification_message=verification_message,
            request_options=request_options,
        )
        return _response.data


class AsyncPhoneClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawPhoneClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawPhoneClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawPhoneClient
        """
        return self._raw_client

    async def get_message_types(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetGuardianFactorPhoneMessageTypesResponseContent:
        """
        Retrieve list of <a href="https://auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa">phone-type MFA factors</a> (i.e., sms and voice) that are enabled for your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetGuardianFactorPhoneMessageTypesResponseContent
            Returns the enabled phone factors

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.factors.phone.get_message_types()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_message_types(request_options=request_options)
        return _response.data

    async def set_message_types(
        self,
        *,
        message_types: typing.Sequence[GuardianFactorPhoneFactorMessageTypeEnum],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetGuardianFactorPhoneMessageTypesResponseContent:
        """
        Replace the list of <a href="https://auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa">phone-type MFA factors</a> (i.e., sms and voice) that are enabled for your tenant.

        Parameters
        ----------
        message_types : typing.Sequence[GuardianFactorPhoneFactorMessageTypeEnum]
            The list of phone factors to enable on the tenant. Can include `sms` and `voice`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianFactorPhoneMessageTypesResponseContent
            Returns selected SMS provider configuration

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.factors.phone.set_message_types(
                message_types=["sms"],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.set_message_types(
            message_types=message_types, request_options=request_options
        )
        return _response.data

    async def get_twilio_provider(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetGuardianFactorsProviderPhoneTwilioResponseContent:
        """
        Retrieve configuration details for a Twilio phone provider that has been set up in your tenant. To learn more, review <a href="https://auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa">Configure SMS and Voice Notifications for MFA</a>.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetGuardianFactorsProviderPhoneTwilioResponseContent
            Twilio Phone configuration successfully retrieved.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.factors.phone.get_twilio_provider()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_twilio_provider(request_options=request_options)
        return _response.data

    async def set_twilio_provider(
        self,
        *,
        from_: typing.Optional[str] = OMIT,
        messaging_service_sid: typing.Optional[str] = OMIT,
        auth_token: typing.Optional[str] = OMIT,
        sid: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetGuardianFactorsProviderPhoneTwilioResponseContent:
        """
        Update the configuration of a Twilio phone provider that has been set up in your tenant. To learn more, review <a href="https://auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa">Configure SMS and Voice Notifications for MFA</a>.

        Parameters
        ----------
        from_ : typing.Optional[str]
            From number

        messaging_service_sid : typing.Optional[str]
            Copilot SID

        auth_token : typing.Optional[str]
            Twilio Authentication token

        sid : typing.Optional[str]
            Twilio SID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianFactorsProviderPhoneTwilioResponseContent
            Twilio Phone configuration successfully updated.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.factors.phone.set_twilio_provider()


        asyncio.run(main())
        """
        _response = await self._raw_client.set_twilio_provider(
            from_=from_,
            messaging_service_sid=messaging_service_sid,
            auth_token=auth_token,
            sid=sid,
            request_options=request_options,
        )
        return _response.data

    async def get_selected_provider(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetGuardianFactorsProviderPhoneResponseContent:
        """
        Retrieve details of the multi-factor authentication phone provider configured for your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetGuardianFactorsProviderPhoneResponseContent
            Returns selected Phone provider configuration

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.factors.phone.get_selected_provider()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_selected_provider(request_options=request_options)
        return _response.data

    async def set_provider(
        self,
        *,
        provider: GuardianFactorsProviderSmsProviderEnum,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetGuardianFactorsProviderPhoneResponseContent:
        """
        Parameters
        ----------
        provider : GuardianFactorsProviderSmsProviderEnum

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianFactorsProviderPhoneResponseContent
            Returns selected Phone provider configuration

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.factors.phone.set_provider(
                provider="auth0",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.set_provider(provider=provider, request_options=request_options)
        return _response.data

    async def get_templates(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetGuardianFactorPhoneTemplatesResponseContent:
        """
        Retrieve details of the multi-factor authentication enrollment and verification templates for phone-type factors available in your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetGuardianFactorPhoneTemplatesResponseContent
            Phone enrollment and verification templates successfully retrieved.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.factors.phone.get_templates()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_templates(request_options=request_options)
        return _response.data

    async def set_templates(
        self,
        *,
        enrollment_message: str,
        verification_message: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SetGuardianFactorPhoneTemplatesResponseContent:
        """
        Customize the messages sent to complete phone enrollment and verification (subscription required).

        Parameters
        ----------
        enrollment_message : str
            Message sent to the user when they are invited to enroll with a phone number.

        verification_message : str
            Message sent to the user when they are prompted to verify their account.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianFactorPhoneTemplatesResponseContent
            Phone enrollment and verification templates successfully updated.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.factors.phone.set_templates(
                enrollment_message="enrollment_message",
                verification_message="verification_message",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.set_templates(
            enrollment_message=enrollment_message,
            verification_message=verification_message,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionUpdatedCloudEventTypeEnum = typing.Union[
    typing.Literal["connection.updated"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .action_trigger import ActionTrigger


class ActionModuleAction(UniversalBaseModel):
    action_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique ID of the action.
    """

    action_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the action.
    """

    module_version_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the module version this action is using.
    """

    module_version_number: typing.Optional[int] = pydantic.Field(default=None)
    """
    The version number of the module this action is using.
    """

    supported_triggers: typing.Optional[typing.List[ActionTrigger]] = pydantic.Field(default=None)
    """
    The triggers that this action supports.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .raw_client import AsyncRawAnomalyClient, RawAnomalyClient

if typing.TYPE_CHECKING:
    from .blocks.client import AsyncBlocksClient, BlocksClient


class AnomalyClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawAnomalyClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._blocks: typing.Optional[BlocksClient] = None

    @property
    def with_raw_response(self) -> RawAnomalyClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawAnomalyClient
        """
        return self._raw_client

    @property
    def blocks(self):
        if self._blocks is None:
            from .blocks.client import BlocksClient  # noqa: E402

            self._blocks = BlocksClient(client_wrapper=self._client_wrapper)
        return self._blocks


class AsyncAnomalyClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawAnomalyClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._blocks: typing.Optional[AsyncBlocksClient] = None

    @property
    def with_raw_response(self) -> AsyncRawAnomalyClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawAnomalyClient
        """
        return self._raw_client

    @property
    def blocks(self):
        if self._blocks is None:
            from .blocks.client import AsyncBlocksClient  # noqa: E402

            self._blocks = AsyncBlocksClient(client_wrapper=self._client_wrapper)
        return self._blocks



# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_airtable_api_key import CreateFlowsVaultConnectionAirtableApiKey
from .create_flows_vault_connection_airtable_uninitialized import CreateFlowsVaultConnectionAirtableUninitialized

CreateFlowsVaultConnectionAirtable = typing.Union[
    CreateFlowsVaultConnectionAirtableApiKey, CreateFlowsVaultConnectionAirtableUninitialized
]



# This file was auto-generated by Fern from our API Definition.

from .connection_scope_array import ConnectionScopeArray

ConnectionScopeLinkedin = ConnectionScopeArray
"""
Scopes to request from LinkedIn during OAuth. Use standard scopes such as r_liteprofile and r_emailaddress; legacy or partner scopes (e.g., r_basicprofile, r_fullprofile, rw_company_admin) may require LinkedIn approval and may not be available to new apps.
"""



from .database import Database
from .delegated import Delegated
from .enterprise import Enterprise
from .get_token import GetToken
from .passwordless import Passwordless
from .revoke_token import RevokeToken
from .social import Social
from .users import Users

__all__ = (
    "Database",
    "Delegated",
    "Enterprise",
    "GetToken",
    "Passwordless",
    "RevokeToken",
    "Social",
    "Users",
)



# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.request_options import RequestOptions
from ....types.create_phone_template_response_content import CreatePhoneTemplateResponseContent
from ....types.create_phone_template_test_notification_response_content import (
    CreatePhoneTemplateTestNotificationResponseContent,
)
from ....types.get_phone_template_response_content import GetPhoneTemplateResponseContent
from ....types.list_phone_templates_response_content import ListPhoneTemplatesResponseContent
from ....types.partial_phone_template_content import PartialPhoneTemplateContent
from ....types.phone_provider_delivery_method_enum import PhoneProviderDeliveryMethodEnum
from ....types.phone_template_content import PhoneTemplateContent
from ....types.phone_template_notification_type_enum import PhoneTemplateNotificationTypeEnum
from ....types.reset_phone_template_request_content import ResetPhoneTemplateRequestContent
from ....types.reset_phone_template_response_content import ResetPhoneTemplateResponseContent
from ....types.update_phone_template_response_content import UpdatePhoneTemplateResponseContent
from .raw_client import AsyncRawTemplatesClient, RawTemplatesClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TemplatesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTemplatesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTemplatesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTemplatesClient
        """
        return self._raw_client

    def list(
        self, *, disabled: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> ListPhoneTemplatesResponseContent:
        """
        Parameters
        ----------
        disabled : typing.Optional[bool]
            Whether the template is enabled (false) or disabled (true).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListPhoneTemplatesResponseContent
            The phone notification templates were retrieved.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.branding.phone.templates.list(
            disabled=True,
        )
        """
        _response = self._raw_client.list(disabled=disabled, request_options=request_options)
        return _response.data

    def create(
        self,
        *,
        type: typing.Optional[PhoneTemplateNotificationTypeEnum] = OMIT,
        disabled: typing.Optional[bool] = OMIT,
        content: typing.Optional[PhoneTemplateContent] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreatePhoneTemplateResponseContent:
        """
        Parameters
        ----------
        type : typing.Optional[PhoneTemplateNotificationTypeEnum]

        disabled : typing.Optional[bool]
            Whether the template is enabled (false) or disabled (true).

        content : typing.Optional[PhoneTemplateContent]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreatePhoneTemplateResponseContent
            The phone notification template was created.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.branding.phone.templates.create()
        """
        _response = self._raw_client.create(
            type=type, disabled=disabled, content=content, request_options=request_options
        )
        return _response.data

    def get(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetPhoneTemplateResponseContent:
        """
        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetPhoneTemplateResponseContent
            The phone notification template were retrieved.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.branding.phone.templates.get(
            id="id",
        )
        """
        _response = self._raw_client.get(id, request_options=request_options)
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.branding.phone.templates.delete(
            id="id",
        )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data

    def update(
        self,
        id: str,
        *,
        content: typing.Optional[PartialPhoneTemplateContent] = OMIT,
        disabled: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdatePhoneTemplateResponseContent:
        """
        Parameters
        ----------
        id : str

        content : typing.Optional[PartialPhoneTemplateContent]

        disabled : typing.Optional[bool]
            Whether the template is enabled (false) or disabled (true).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdatePhoneTemplateResponseContent
            The phone notification template was updated.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.branding.phone.templates.update(
            id="id",
        )
        """
        _response = self._raw_client.update(id, content=content, disabled=disabled, request_options=request_options)
        return _response.data

    def reset(
        self,
        id: str,
        *,
        request: ResetPhoneTemplateRequestContent,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResetPhoneTemplateResponseContent:
        """
        Parameters
        ----------
        id : str

        request : ResetPhoneTemplateRequestContent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResetPhoneTemplateResponseContent
            The phone notification template was reset.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.branding.phone.templates.reset(
            id="id",
            request={"key": "value"},
        )
        """
        _response = self._raw_client.reset(id, request=request, request_options=request_options)
        return _response.data

    def test(
        self,
        id: str,
        *,
        to: str,
        delivery_method: typing.Optional[PhoneProviderDeliveryMethodEnum] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreatePhoneTemplateTestNotificationResponseContent:
        """
        Parameters
        ----------
        id : str

        to : str
            Destination of the testing phone notification

        delivery_method : typing.Optional[PhoneProviderDeliveryMethodEnum]
            Medium to use to send the notification

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreatePhoneTemplateTestNotificationResponseContent
            The phone testing notification for the template was sent

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.branding.phone.templates.test(
            id="id",
            to="to",
        )
        """
        _response = self._raw_client.test(id, to=to, delivery_method=delivery_method, request_options=request_options)
        return _response.data


class AsyncTemplatesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTemplatesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTemplatesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTemplatesClient
        """
        return self._raw_client

    async def list(
        self, *, disabled: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> ListPhoneTemplatesResponseContent:
        """
        Parameters
        ----------
        disabled : typing.Optional[bool]
            Whether the template is enabled (false) or disabled (true).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListPhoneTemplatesResponseContent
            The phone notification templates were retrieved.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.branding.phone.templates.list(
                disabled=True,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(disabled=disabled, request_options=request_options)
        return _response.data

    async def create(
        self,
        *,
        type: typing.Optional[PhoneTemplateNotificationTypeEnum] = OMIT,
        disabled: typing.Optional[bool] = OMIT,
        content: typing.Optional[PhoneTemplateContent] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreatePhoneTemplateResponseContent:
        """
        Parameters
        ----------
        type : typing.Optional[PhoneTemplateNotificationTypeEnum]

        disabled : typing.Optional[bool]
            Whether the template is enabled (false) or disabled (true).

        content : typing.Optional[PhoneTemplateContent]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreatePhoneTemplateResponseContent
            The phone notification template was created.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.branding.phone.templates.create()


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            type=type, disabled=disabled, content=content, request_options=request_options
        )
        return _response.data

    async def get(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetPhoneTemplateResponseContent:
        """
        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetPhoneTemplateResponseContent
            The phone notification template were retrieved.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.branding.phone.templates.get(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, request_options=request_options)
        return _response.data

    async def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.branding.phone.templates.delete(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data

    async def update(
        self,
        id: str,
        *,
        content: typing.Optional[PartialPhoneTemplateContent] = OMIT,
        disabled: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdatePhoneTemplateResponseContent:
        """
        Parameters
        ----------
        id : str

        content : typing.Optional[PartialPhoneTemplateContent]

        disabled : typing.Optional[bool]
            Whether the template is enabled (false) or disabled (true).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdatePhoneTemplateResponseContent
            The phone notification template was updated.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.branding.phone.templates.update(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            id, content=content, disabled=disabled, request_options=request_options
        )
        return _response.data

    async def reset(
        self,
        id: str,
        *,
        request: ResetPhoneTemplateRequestContent,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResetPhoneTemplateResponseContent:
        """
        Parameters
        ----------
        id : str

        request : ResetPhoneTemplateRequestContent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResetPhoneTemplateResponseContent
            The phone notification template was reset.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.branding.phone.templates.reset(
                id="id",
                request={"key": "value"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.reset(id, request=request, request_options=request_options)
        return _response.data

    async def test(
        self,
        id: str,
        *,
        to: str,
        delivery_method: typing.Optional[PhoneProviderDeliveryMethodEnum] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreatePhoneTemplateTestNotificationResponseContent:
        """
        Parameters
        ----------
        id : str

        to : str
            Destination of the testing phone notification

        delivery_method : typing.Optional[PhoneProviderDeliveryMethodEnum]
            Medium to use to send the notification

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreatePhoneTemplateTestNotificationResponseContent
            The phone testing notification for the template was sent

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.branding.phone.templates.test(
                id="id",
                to="to",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.test(
            id, to=to, delivery_method=delivery_method, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .organization_branding import OrganizationBranding
from .organization_metadata import OrganizationMetadata
from .organization_third_party_client_access_enum import OrganizationThirdPartyClientAccessEnum
from .token_quota import TokenQuota


class GetOrganizationResponseContent(UniversalBaseModel):
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Organization identifier.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of this organization.
    """

    display_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Friendly name of this organization.
    """

    branding: typing.Optional[OrganizationBranding] = None
    metadata: typing.Optional[OrganizationMetadata] = None
    token_quota: typing.Optional[TokenQuota] = None
    third_party_client_access: typing.Optional[OrganizationThirdPartyClientAccessEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

BrandingThemeIdentifiersPhoneDisplayFormattingEnum = typing.Union[
    typing.Literal["international", "regional"], typing.Any
]



from .conftest import get_client, verify_request_count


def test_guardian_factors_list_() -> None:
    """Test list endpoint with WireMock"""
    test_id = "guardian.factors.list_.0"
    client = get_client(test_id)
    client.guardian.factors.list()
    verify_request_count(test_id, "GET", "/guardian/factors", None, 1)


def test_guardian_factors_set_() -> None:
    """Test set endpoint with WireMock"""
    test_id = "guardian.factors.set_.0"
    client = get_client(test_id)
    client.guardian.factors.set(
        name="push-notification",
        enabled=True,
    )
    verify_request_count(test_id, "PUT", "/guardian/factors/push-notification", None, 1)



# This file was auto-generated by Fern from our API Definition.

import typing

from .set_user_authentication_methods import SetUserAuthenticationMethods

SetUserAuthenticationMethodsRequestContent = typing.List[SetUserAuthenticationMethods]



from .conftest import get_client, verify_request_count


def test_organizations_enabledConnections_list_() -> None:
    """Test list endpoint with WireMock"""
    test_id = "organizations.enabled_connections.list_.0"
    client = get_client(test_id)
    client.organizations.enabled_connections.list(
        id="id",
        page=1,
        per_page=1,
        include_totals=True,
    )
    verify_request_count(
        test_id,
        "GET",
        "/organizations/id/enabled_connections",
        {"page": "1", "per_page": "1", "include_totals": "true"},
        1,
    )


def test_organizations_enabledConnections_add() -> None:
    """Test add endpoint with WireMock"""
    test_id = "organizations.enabled_connections.add.0"
    client = get_client(test_id)
    client.organizations.enabled_connections.add(
        id="id",
        connection_id="connection_id",
    )
    verify_request_count(test_id, "POST", "/organizations/id/enabled_connections", None, 1)


def test_organizations_enabledConnections_get() -> None:
    """Test get endpoint with WireMock"""
    test_id = "organizations.enabled_connections.get.0"
    client = get_client(test_id)
    client.organizations.enabled_connections.get(
        id="id",
        connection_id="connectionId",
    )
    verify_request_count(test_id, "GET", "/organizations/id/enabled_connections/connectionId", None, 1)


def test_organizations_enabledConnections_delete() -> None:
    """Test delete endpoint with WireMock"""
    test_id = "organizations.enabled_connections.delete.0"
    client = get_client(test_id)
    client.organizations.enabled_connections.delete(
        id="id",
        connection_id="connectionId",
    )
    verify_request_count(test_id, "DELETE", "/organizations/id/enabled_connections/connectionId", None, 1)


def test_organizations_enabledConnections_update() -> None:
    """Test update endpoint with WireMock"""
    test_id = "organizations.enabled_connections.update.0"
    client = get_client(test_id)
    client.organizations.enabled_connections.update(
        id="id",
        connection_id="connectionId",
    )
    verify_request_count(test_id, "PATCH", "/organizations/id/enabled_connections/connectionId", None, 1)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.pagination import AsyncPager, SyncPager
from ...core.request_options import RequestOptions
from ...types.list_organization_members_paginated_response_content import (
    ListOrganizationMembersPaginatedResponseContent,
)
from ...types.organization_member import OrganizationMember
from .raw_client import AsyncRawMembersClient, RawMembersClient

if typing.TYPE_CHECKING:
    from .effective_roles.client import AsyncEffectiveRolesClient, EffectiveRolesClient
    from .roles.client import AsyncRolesClient, RolesClient
# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class MembersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawMembersClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._effective_roles: typing.Optional[EffectiveRolesClient] = None
        self._roles: typing.Optional[RolesClient] = None

    @property
    def with_raw_response(self) -> RawMembersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawMembersClient
        """
        return self._raw_client

    def list(
        self,
        id: str,
        *,
        from_: typing.Optional[str] = None,
        take: typing.Optional[int] = 50,
        fields: typing.Optional[str] = None,
        include_fields: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[OrganizationMember, ListOrganizationMembersPaginatedResponseContent]:
        """
        List organization members.
        This endpoint is subject to eventual consistency. New users may not be immediately included in the response and deleted users may not be immediately removed from it.

        - Use the `fields` parameter to optionally define the specific member details retrieved. If `fields` is left blank, all fields (except roles) are returned.
        - Member roles are not sent by default. Use `fields=roles` to retrieve the roles assigned to each listed member. To use this parameter, you must include the `read:organization_member_roles` scope in the token.

        This endpoint supports two types of pagination:

        - Offset pagination
        - Checkpoint pagination

        Checkpoint pagination must be used if you need to retrieve more than 1000 organization members.

        **Checkpoint Pagination**

        To search by checkpoint, use the following parameters: - from: Optional id from which to start selection. - take: The total amount of entries to retrieve when using the from parameter. Defaults to 50. Note: The first time you call this endpoint using Checkpoint Pagination, you should omit the `from` parameter. If there are more results, a `next` value will be included in the response. You can use this for subsequent API calls. When `next` is no longer included in the response, this indicates there are no more pages remaining.

        Parameters
        ----------
        id : str
            Organization identifier.

        from_ : typing.Optional[str]
            Optional Id from which to start selection.

        take : typing.Optional[int]
            Number of results per page. Defaults to 50.

        fields : typing.Optional[str]
            Comma-separated list of fields to include or exclude (based on value provided for include_fields) in the result. Leave empty to retrieve all fields.

        include_fields : typing.Optional[bool]
            Whether specified fields are to be included (true) or excluded (false).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[OrganizationMember, ListOrganizationMembersPaginatedResponseContent]
            Members successfully retrieved.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        response = client.organizations.members.list(
            id="id",
            from_="from",
            take=1,
            fields="fields",
            include_fields=True,
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.list(
            id, from_=from_, take=take, fields=fields, include_fields=include_fields, request_options=request_options
        )

    def create(
        self, id: str, *, members: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Set one or more existing users as members of a specific [Organization](https://auth0.com/docs/manage-users/organizations).

        To add a user to an Organization through this action, the user must already exist in your tenant. If a user does not yet exist, you can [invite them to create an account](https://auth0.com/docs/manage-users/organizations/configure-organizations/invite-members), manually create them through the Auth0 Dashboard, or use the Management API.

        Parameters
        ----------
        id : str
            Organization identifier.

        members : typing.Sequence[str]
            List of user IDs to add to the organization as members.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.organizations.members.create(
            id="id",
            members=["members"],
        )
        """
        _response = self._raw_client.create(id, members=members, request_options=request_options)
        return _response.data

    def delete(
        self, id: str, *, members: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        id : str
            Organization identifier.

        members : typing.Sequence[str]
            List of user IDs to remove from the organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.organizations.members.delete(
            id="id",
            members=["members"],
        )
        """
        _response = self._raw_client.delete(id, members=members, request_options=request_options)
        return _response.data

    @property
    def effective_roles(self):
        if self._effective_roles is None:
            from .effective_roles.client import EffectiveRolesClient  # noqa: E402

            self._effective_roles = EffectiveRolesClient(client_wrapper=self._client_wrapper)
        return self._effective_roles

    @property
    def roles(self):
        if self._roles is None:
            from .roles.client import RolesClient  # noqa: E402

            self._roles = RolesClient(client_wrapper=self._client_wrapper)
        return self._roles


class AsyncMembersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawMembersClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._effective_roles: typing.Optional[AsyncEffectiveRolesClient] = None
        self._roles: typing.Optional[AsyncRolesClient] = None

    @property
    def with_raw_response(self) -> AsyncRawMembersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawMembersClient
        """
        return self._raw_client

    async def list(
        self,
        id: str,
        *,
        from_: typing.Optional[str] = None,
        take: typing.Optional[int] = 50,
        fields: typing.Optional[str] = None,
        include_fields: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[OrganizationMember, ListOrganizationMembersPaginatedResponseContent]:
        """
        List organization members.
        This endpoint is subject to eventual consistency. New users may not be immediately included in the response and deleted users may not be immediately removed from it.

        - Use the `fields` parameter to optionally define the specific member details retrieved. If `fields` is left blank, all fields (except roles) are returned.
        - Member roles are not sent by default. Use `fields=roles` to retrieve the roles assigned to each listed member. To use this parameter, you must include the `read:organization_member_roles` scope in the token.

        This endpoint supports two types of pagination:

        - Offset pagination
        - Checkpoint pagination

        Checkpoint pagination must be used if you need to retrieve more than 1000 organization members.

        **Checkpoint Pagination**

        To search by checkpoint, use the following parameters: - from: Optional id from which to start selection. - take: The total amount of entries to retrieve when using the from parameter. Defaults to 50. Note: The first time you call this endpoint using Checkpoint Pagination, you should omit the `from` parameter. If there are more results, a `next` value will be included in the response. You can use this for subsequent API calls. When `next` is no longer included in the response, this indicates there are no more pages remaining.

        Parameters
        ----------
        id : str
            Organization identifier.

        from_ : typing.Optional[str]
            Optional Id from which to start selection.

        take : typing.Optional[int]
            Number of results per page. Defaults to 50.

        fields : typing.Optional[str]
            Comma-separated list of fields to include or exclude (based on value provided for include_fields) in the result. Leave empty to retrieve all fields.

        include_fields : typing.Optional[bool]
            Whether specified fields are to be included (true) or excluded (false).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[OrganizationMember, ListOrganizationMembersPaginatedResponseContent]
            Members successfully retrieved.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            response = await client.organizations.members.list(
                id="id",
                from_="from",
                take=1,
                fields="fields",
                include_fields=True,
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.list(
            id, from_=from_, take=take, fields=fields, include_fields=include_fields, request_options=request_options
        )

    async def create(
        self, id: str, *, members: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Set one or more existing users as members of a specific [Organization](https://auth0.com/docs/manage-users/organizations).

        To add a user to an Organization through this action, the user must already exist in your tenant. If a user does not yet exist, you can [invite them to create an account](https://auth0.com/docs/manage-users/organizations/configure-organizations/invite-members), manually create them through the Auth0 Dashboard, or use the Management API.

        Parameters
        ----------
        id : str
            Organization identifier.

        members : typing.Sequence[str]
            List of user IDs to add to the organization as members.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.organizations.members.create(
                id="id",
                members=["members"],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(id, members=members, request_options=request_options)
        return _response.data

    async def delete(
        self, id: str, *, members: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        id : str
            Organization identifier.

        members : typing.Sequence[str]
            List of user IDs to remove from the organization.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.organizations.members.delete(
                id="id",
                members=["members"],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, members=members, request_options=request_options)
        return _response.data

    @property
    def effective_roles(self):
        if self._effective_roles is None:
            from .effective_roles.client import AsyncEffectiveRolesClient  # noqa: E402

            self._effective_roles = AsyncEffectiveRolesClient(client_wrapper=self._client_wrapper)
        return self._effective_roles

    @property
    def roles(self):
        if self._roles is None:
            from .roles.client import AsyncRolesClient  # noqa: E402

            self._roles = AsyncRolesClient(client_wrapper=self._client_wrapper)
        return self._roles



# This file was auto-generated by Fern from our API Definition.

import typing

NetworkAclRuleScopeEnum = typing.Union[
    typing.Literal["management", "authentication", "tenant", "dynamic_client_registration"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .enabled_features_enum import EnabledFeaturesEnum

ConnectionProfileEnabledFeatures = typing.List[EnabledFeaturesEnum]
"""
Enabled features for the connection profile.
"""



# This file was auto-generated by Fern from our API Definition.

ConnectionScopeOidc = str
"""
Space-separated list of OAuth 2.0 scopes requested during authorization. Must include 'openid' (required by OIDC spec). Common values: 'openid profile email'. Additional scopes depend on the identity provider.
"""



# This file was auto-generated by Fern from our API Definition.

ConnectionTokenEndpoint = str
"""
URL of the identity provider's OAuth 2.0 token endpoint where authorization codes are exchanged for access tokens. Must be a valid HTTPS URL. Required for authorization code flow but optional for implicit flow.
"""



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_org_group_role_deleted_object_group import (
    EventStreamCloudEventOrgGroupRoleDeletedObjectGroup,
)
from .event_stream_cloud_event_org_group_role_deleted_object_organization import (
    EventStreamCloudEventOrgGroupRoleDeletedObjectOrganization,
)
from .event_stream_cloud_event_org_group_role_deleted_object_role import (
    EventStreamCloudEventOrgGroupRoleDeletedObjectRole,
)


class EventStreamCloudEventOrgGroupRoleDeletedObject(UniversalBaseModel):
    """
    The event content.
    """

    organization: EventStreamCloudEventOrgGroupRoleDeletedObjectOrganization
    role: EventStreamCloudEventOrgGroupRoleDeletedObjectRole
    group: EventStreamCloudEventOrgGroupRoleDeletedObjectGroup
    deleted_at: dt.datetime = pydantic.Field()
    """
    The time at which the role was removed from the group in the organization.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.rules_config import RulesConfig
from ..types.set_rules_config_response_content import SetRulesConfigResponseContent
from .raw_client import AsyncRawRulesConfigsClient, RawRulesConfigsClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RulesConfigsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawRulesConfigsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawRulesConfigsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawRulesConfigsClient
        """
        return self._raw_client

    def list(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.List[RulesConfig]:
        """
        Retrieve rules config variable keys.

            Note: For security, config variable values cannot be retrieved outside rule execution.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[RulesConfig]
            Rules config keys successfully retrieved.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.rules_configs.list()
        """
        _response = self._raw_client.list(request_options=request_options)
        return _response.data

    def set(
        self, key: str, *, value: str, request_options: typing.Optional[RequestOptions] = None
    ) -> SetRulesConfigResponseContent:
        """
        Sets a rules config variable.

        Parameters
        ----------
        key : str
            Key of the rules config variable to set (max length: 127 characters).

        value : str
            Value for a rules config variable.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetRulesConfigResponseContent
            Rules config variable successfully set.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.rules_configs.set(
            key="key",
            value="value",
        )
        """
        _response = self._raw_client.set(key, value=value, request_options=request_options)
        return _response.data

    def delete(self, key: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Delete a rules config variable identified by its key.

        Parameters
        ----------
        key : str
            Key of the rules config variable to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.rules_configs.delete(
            key="key",
        )
        """
        _response = self._raw_client.delete(key, request_options=request_options)
        return _response.data


class AsyncRulesConfigsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawRulesConfigsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawRulesConfigsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawRulesConfigsClient
        """
        return self._raw_client

    async def list(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.List[RulesConfig]:
        """
        Retrieve rules config variable keys.

            Note: For security, config variable values cannot be retrieved outside rule execution.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[RulesConfig]
            Rules config keys successfully retrieved.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.rules_configs.list()


        asyncio.run(main())
        """
        _response = await self._raw_client.list(request_options=request_options)
        return _response.data

    async def set(
        self, key: str, *, value: str, request_options: typing.Optional[RequestOptions] = None
    ) -> SetRulesConfigResponseContent:
        """
        Sets a rules config variable.

        Parameters
        ----------
        key : str
            Key of the rules config variable to set (max length: 127 characters).

        value : str
            Value for a rules config variable.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetRulesConfigResponseContent
            Rules config variable successfully set.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.rules_configs.set(
                key="key",
                value="value",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.set(key, value=value, request_options=request_options)
        return _response.data

    async def delete(self, key: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Delete a rules config variable identified by its key.

        Parameters
        ----------
        key : str
            Key of the rules config variable to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.rules_configs.delete(
                key="key",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(key, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_org_group_role_assigned_object_group_0 import (
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup0,
)
from .event_stream_cloud_event_org_group_role_assigned_object_group_1 import (
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup1,
)
from .event_stream_cloud_event_org_group_role_assigned_object_group_2 import (
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup2,
)

EventStreamCloudEventOrgGroupRoleAssignedObjectGroup = typing.Union[
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup0,
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup1,
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup2,
]



from .conftest import get_client, verify_request_count


def test_users_connectedAccounts_list_() -> None:
    """Test list endpoint with WireMock"""
    test_id = "users.connected_accounts.list_.0"
    client = get_client(test_id)
    client.users.connected_accounts.list(
        id="id",
        from_="from",
        take=1,
    )
    verify_request_count(test_id, "GET", "/users/id/connected-accounts", {"from": "from", "take": "1"}, 1)



from .conftest import get_client, verify_request_count


def test_eventStreams_deliveries_list_() -> None:
    """Test list endpoint with WireMock"""
    test_id = "event_streams.deliveries.list_.0"
    client = get_client(test_id)
    client.event_streams.deliveries.list(
        id="id",
        statuses="statuses",
        event_types="event_types",
        date_from="date_from",
        date_to="date_to",
        from_="from",
        take=1,
    )
    verify_request_count(
        test_id,
        "GET",
        "/event-streams/id/deliveries",
        {
            "statuses": "statuses",
            "event_types": "event_types",
            "date_from": "date_from",
            "date_to": "date_to",
            "from": "from",
            "take": "1",
        },
        1,
    )


def test_eventStreams_deliveries_get_history() -> None:
    """Test getHistory endpoint with WireMock"""
    test_id = "event_streams.deliveries.get_history.0"
    client = get_client(test_id)
    client.event_streams.deliveries.get_history(
        id="id",
        event_id="event_id",
    )
    verify_request_count(test_id, "GET", "/event-streams/id/deliveries/event_id", None, 1)



# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_activecampaign_api_key import CreateFlowsVaultConnectionActivecampaignApiKey
from .create_flows_vault_connection_activecampaign_uninitialized import (
    CreateFlowsVaultConnectionActivecampaignUninitialized,
)

CreateFlowsVaultConnectionActivecampaign = typing.Union[
    CreateFlowsVaultConnectionActivecampaignApiKey, CreateFlowsVaultConnectionActivecampaignUninitialized
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .scim_token_item import ScimTokenItem

GetScimTokensResponseContent = typing.List[ScimTokenItem]
"""
The list of scim tokens for scim clients
"""



# This file was auto-generated by Fern from our API Definition.

import typing

AttackProtectionCaptchaProviderId = typing.Union[
    typing.Literal[
        "arkose",
        "auth_challenge",
        "friendly_captcha",
        "hcaptcha",
        "recaptcha_v2",
        "recaptcha_enterprise",
        "simple_captcha",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .acul_context_configuration import AculContextConfiguration
from .acul_filters import AculFilters
from .acul_head_tag import AculHeadTag
from .acul_rendering_mode_enum import AculRenderingModeEnum


class GetAculResponseContent(UniversalBaseModel):
    tenant: typing.Optional[str] = pydantic.Field(default=None)
    """
    Tenant ID
    """

    prompt: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the prompt
    """

    screen: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the screen
    """

    rendering_mode: typing.Optional[AculRenderingModeEnum] = pydantic.Field(default=None)
    """
    Rendering mode
    """

    context_configuration: typing.Optional[AculContextConfiguration] = None
    default_head_tags_disabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Override Universal Login default head tags
    """

    use_page_template: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Use page template with ACUL
    """

    head_tags: typing.Optional[typing.List[AculHeadTag]] = pydantic.Field(default=None)
    """
    An array of head tags
    """

    filters: typing.Optional[AculFilters] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

IntegrationFeatureTypeEnum = typing.Union[
    typing.Literal["unspecified", "action", "social_connection", "log_stream", "sso_integration", "sms_provider"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.list_guardian_policies_response_content import ListGuardianPoliciesResponseContent
from ...types.set_guardian_policies_request_content import SetGuardianPoliciesRequestContent
from ...types.set_guardian_policies_response_content import SetGuardianPoliciesResponseContent
from .raw_client import AsyncRawPoliciesClient, RawPoliciesClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class PoliciesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawPoliciesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawPoliciesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawPoliciesClient
        """
        return self._raw_client

    def list(self, *, request_options: typing.Optional[RequestOptions] = None) -> ListGuardianPoliciesResponseContent:
        """
        Retrieve the [multi-factor authentication (MFA) policies](https://auth0.com/docs/secure/multi-factor-authentication/enable-mfa) configured for your tenant.

        The following policies are supported:

        - `all-applications` policy prompts with MFA for all logins.
        - `confidence-score` policy prompts with MFA only for low confidence logins.

        **Note**: The `confidence-score` policy is part of the [Adaptive MFA feature](https://auth0.com/docs/secure/multi-factor-authentication/adaptive-mfa). Adaptive MFA requires an add-on for the Enterprise plan; review [Auth0 Pricing](https://auth0.com/pricing) for more details.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListGuardianPoliciesResponseContent
            Success

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.policies.list()
        """
        _response = self._raw_client.list(request_options=request_options)
        return _response.data

    def set(
        self, *, request: SetGuardianPoliciesRequestContent, request_options: typing.Optional[RequestOptions] = None
    ) -> SetGuardianPoliciesResponseContent:
        """
        Set [multi-factor authentication (MFA) policies](https://auth0.com/docs/secure/multi-factor-authentication/enable-mfa) for your tenant.

        The following policies are supported:

        - `all-applications` policy prompts with MFA for all logins.
        - `confidence-score` policy prompts with MFA only for low confidence logins.

        **Note**: The `confidence-score` policy is part of the [Adaptive MFA feature](https://auth0.com/docs/secure/multi-factor-authentication/adaptive-mfa). Adaptive MFA requires an add-on for the Enterprise plan; review [Auth0 Pricing](https://auth0.com/pricing) for more details.

        Parameters
        ----------
        request : SetGuardianPoliciesRequestContent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianPoliciesResponseContent
            Policies updated

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        client.guardian.policies.set(
            request=["all-applications"],
        )
        """
        _response = self._raw_client.set(request=request, request_options=request_options)
        return _response.data


class AsyncPoliciesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawPoliciesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawPoliciesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawPoliciesClient
        """
        return self._raw_client

    async def list(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ListGuardianPoliciesResponseContent:
        """
        Retrieve the [multi-factor authentication (MFA) policies](https://auth0.com/docs/secure/multi-factor-authentication/enable-mfa) configured for your tenant.

        The following policies are supported:

        - `all-applications` policy prompts with MFA for all logins.
        - `confidence-score` policy prompts with MFA only for low confidence logins.

        **Note**: The `confidence-score` policy is part of the [Adaptive MFA feature](https://auth0.com/docs/secure/multi-factor-authentication/adaptive-mfa). Adaptive MFA requires an add-on for the Enterprise plan; review [Auth0 Pricing](https://auth0.com/pricing) for more details.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListGuardianPoliciesResponseContent
            Success

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.policies.list()


        asyncio.run(main())
        """
        _response = await self._raw_client.list(request_options=request_options)
        return _response.data

    async def set(
        self, *, request: SetGuardianPoliciesRequestContent, request_options: typing.Optional[RequestOptions] = None
    ) -> SetGuardianPoliciesResponseContent:
        """
        Set [multi-factor authentication (MFA) policies](https://auth0.com/docs/secure/multi-factor-authentication/enable-mfa) for your tenant.

        The following policies are supported:

        - `all-applications` policy prompts with MFA for all logins.
        - `confidence-score` policy prompts with MFA only for low confidence logins.

        **Note**: The `confidence-score` policy is part of the [Adaptive MFA feature](https://auth0.com/docs/secure/multi-factor-authentication/adaptive-mfa). Adaptive MFA requires an add-on for the Enterprise plan; review [Auth0 Pricing](https://auth0.com/pricing) for more details.

        Parameters
        ----------
        request : SetGuardianPoliciesRequestContent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SetGuardianPoliciesResponseContent
            Policies updated

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.guardian.policies.set(
                request=["all-applications"],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.set(request=request, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

ConnectionGlobalTokenRevocationJwtIssSaml = str
"""
Expected 'iss' (Issuer) claim value for JWT tokens in Global Token Revocation requests from the identity provider. When configured, Auth0 validates the JWT issuer matches this value before processing token revocation. Must be used together with global_token_revocation_jwt_sub.
"""



# This file was auto-generated by Fern from our API Definition.

from .connection_icon_url import ConnectionIconUrl

ConnectionIconUrlAzureAd = ConnectionIconUrl
"""
URL for the connection icon displayed in Auth0 login pages. Accepts HTTPS URLs. Used for visual branding in authentication flows.
"""



from .conftest import get_client, verify_request_count


def test_selfServiceProfiles_customText_list_() -> None:
    """Test list endpoint with WireMock"""
    test_id = "self_service_profiles.custom_text.list_.0"
    client = get_client(test_id)
    client.self_service_profiles.custom_text.list(
        id="id",
        language="en",
        page="get-started",
    )
    verify_request_count(test_id, "GET", "/self-service-profiles/id/custom-text/en/get-started", None, 1)


def test_selfServiceProfiles_customText_set_() -> None:
    """Test set endpoint with WireMock"""
    test_id = "self_service_profiles.custom_text.set_.0"
    client = get_client(test_id)
    client.self_service_profiles.custom_text.set(
        id="id",
        language="en",
        page="get-started",
        request={"key": "value"},
    )
    verify_request_count(test_id, "PUT", "/self-service-profiles/id/custom-text/en/get-started", None, 1)



from .conftest import get_client, verify_request_count


def test_prompts_partials_get() -> None:
    """Test get endpoint with WireMock"""
    test_id = "prompts.partials.get.0"
    client = get_client(test_id)
    client.prompts.partials.get(
        prompt="login",
    )
    verify_request_count(test_id, "GET", "/prompts/login/partials", None, 1)


def test_prompts_partials_set_() -> None:
    """Test set endpoint with WireMock"""
    test_id = "prompts.partials.set_.0"
    client = get_client(test_id)
    client.prompts.partials.set(
        prompt="login",
        request={"key": "value"},
    )
    verify_request_count(test_id, "PUT", "/prompts/login/partials", None, 1)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
from email.utils import parsedate_to_datetime
from typing import Any

import pydantic

IS_PYDANTIC_V2 = pydantic.VERSION.startswith("2.")


def parse_rfc2822_datetime(v: Any) -> dt.datetime:
    """
    Parse an RFC 2822 datetime string (e.g., "Wed, 02 Oct 2002 13:00:00 GMT")
    into a datetime object. If the value is already a datetime, return it as-is.
    Falls back to ISO 8601 parsing if RFC 2822 parsing fails.
    """
    if isinstance(v, dt.datetime):
        return v
    if isinstance(v, str):
        try:
            return parsedate_to_datetime(v)
        except Exception:
            pass
        # Fallback to ISO 8601 parsing
        return dt.datetime.fromisoformat(v.replace("Z", "+00:00"))
    raise ValueError(f"Expected str or datetime, got {type(v)}")


class Rfc2822DateTime(dt.datetime):
    """A datetime subclass that parses RFC 2822 date strings.

    On Pydantic V1, uses __get_validators__ for pre-validation.
    On Pydantic V2, uses __get_pydantic_core_schema__ for BeforeValidator-style parsing.
    """

    @classmethod
    def __get_validators__(cls):  # type: ignore[no-untyped-def]
        yield parse_rfc2822_datetime

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type: Any, _handler: Any) -> Any:  # type: ignore[override]
        from pydantic_core import core_schema

        return core_schema.no_info_before_validator_function(parse_rfc2822_datetime, core_schema.datetime_schema())


def serialize_datetime(v: dt.datetime) -> str:
    """
    Serialize a datetime including timezone info.

    Uses the timezone info provided if present, otherwise uses the current runtime's timezone info.

    UTC datetimes end in "Z" while all other timezones are represented as offset from UTC, e.g. +05:00.
    """

    def _serialize_zoned_datetime(v: dt.datetime) -> str:
        if v.tzinfo is not None and v.tzinfo.tzname(None) == dt.timezone.utc.tzname(None):
            # UTC is a special case where we use "Z" at the end instead of "+00:00"
            return v.isoformat().replace("+00:00", "Z")
        else:
            # Delegate to the typical +/- offset format
            return v.isoformat()

    if v.tzinfo is not None:
        return _serialize_zoned_datetime(v)
    else:
        local_tz = dt.datetime.now().astimezone().tzinfo
        localized_dt = v.replace(tzinfo=local_tz)
        return _serialize_zoned_datetime(localized_dt)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .connection_authentication_purpose import ConnectionAuthenticationPurpose
from .connection_common import ConnectionCommon
from .connection_connected_accounts_purpose_xaa import ConnectionConnectedAccountsPurposeXaa
from .connection_cross_app_access_resource_app import ConnectionCrossAppAccessResourceApp
from .connection_options_oidc import ConnectionOptionsOidc
from .connection_show_as_button import ConnectionShowAsButton
from .cross_app_access_requesting_app import CrossAppAccessRequestingApp


class UpdateConnectionRequestContentOidc(ConnectionCommon):
    """
    Update a connection with strategy=oidc
    """

    options: typing.Optional[ConnectionOptionsOidc] = None
    authentication: typing.Optional[ConnectionAuthenticationPurpose] = None
    connected_accounts: typing.Optional[ConnectionConnectedAccountsPurposeXaa] = None
    cross_app_access_requesting_app: typing.Optional[CrossAppAccessRequestingApp] = None
    cross_app_access_resource_app: typing.Optional[ConnectionCrossAppAccessResourceApp] = None
    show_as_button: typing.Optional[ConnectionShowAsButton] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ....core.api_error import ApiError
from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.http_response import AsyncHttpResponse, HttpResponse
from ....core.parse_error import ParsingError
from ....core.pydantic_utilities import parse_obj_as
from ....core.request_options import RequestOptions
from ....errors.bad_request_error import BadRequestError
from ....errors.forbidden_error import ForbiddenError
from ....errors.unauthorized_error import UnauthorizedError
from ....types.get_guardian_factor_sms_templates_response_content import GetGuardianFactorSmsTemplatesResponseContent
from ....types.get_guardian_factors_provider_sms_response_content import GetGuardianFactorsProviderSmsResponseContent
from ....types.get_guardian_factors_provider_sms_twilio_response_content import (
    GetGuardianFactorsProviderSmsTwilioResponseContent,
)
from ....types.guardian_factors_provider_sms_provider_enum import GuardianFactorsProviderSmsProviderEnum
from ....types.set_guardian_factor_sms_templates_response_content import SetGuardianFactorSmsTemplatesResponseContent
from ....types.set_guardian_factors_provider_sms_response_content import SetGuardianFactorsProviderSmsResponseContent
from ....types.set_guardian_factors_provider_sms_twilio_response_content import (
    SetGuardianFactorsProviderSmsTwilioResponseContent,
)
from pydantic import ValidationError

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawSmsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_twilio_provider(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[GetGuardianFactorsProviderSmsTwilioResponseContent]:
        """
        Retrieve the <a href="https://auth0.com/docs/multifactor-authentication/twilio-configuration">Twilio SMS provider configuration</a> (subscription required).

            A new endpoint is available to retrieve the Twilio configuration related to phone factors (<a href='https://auth0.com/docs/api/management/v2/#!/Guardian/get_twilio'>phone Twilio configuration</a>). It has the same payload as this one. Please use it instead.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetGuardianFactorsProviderSmsTwilioResponseContent]
            Twilio SMS configuration successfully retrieved.
        """
        _response = self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/providers/twilio",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetGuardianFactorsProviderSmsTwilioResponseContent,
                    parse_obj_as(
                        type_=GetGuardianFactorsProviderSmsTwilioResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def set_twilio_provider(
        self,
        *,
        from_: typing.Optional[str] = OMIT,
        messaging_service_sid: typing.Optional[str] = OMIT,
        auth_token: typing.Optional[str] = OMIT,
        sid: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SetGuardianFactorsProviderSmsTwilioResponseContent]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/put-twilio">Update Twilio phone configuration</a> endpoint.

            <b>Previous functionality</b>: Update the Twilio SMS provider configuration.

        Parameters
        ----------
        from_ : typing.Optional[str]
            From number

        messaging_service_sid : typing.Optional[str]
            Copilot SID

        auth_token : typing.Optional[str]
            Twilio Authentication token

        sid : typing.Optional[str]
            Twilio SID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SetGuardianFactorsProviderSmsTwilioResponseContent]
            Twilio SMS configuration successfully updated.
        """
        _response = self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/providers/twilio",
            method="PUT",
            json={
                "from": from_,
                "messaging_service_sid": messaging_service_sid,
                "auth_token": auth_token,
                "sid": sid,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetGuardianFactorsProviderSmsTwilioResponseContent,
                    parse_obj_as(
                        type_=SetGuardianFactorsProviderSmsTwilioResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_selected_provider(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[GetGuardianFactorsProviderSmsResponseContent]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/get-phone-providers">Retrieve phone configuration</a> endpoint instead.

            <b>Previous functionality</b>: Retrieve details for the multi-factor authentication SMS provider configured for your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetGuardianFactorsProviderSmsResponseContent]
            Returns selected SMS provider configuration
        """
        _response = self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/selected-provider",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetGuardianFactorsProviderSmsResponseContent,
                    parse_obj_as(
                        type_=GetGuardianFactorsProviderSmsResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def set_provider(
        self,
        *,
        provider: GuardianFactorsProviderSmsProviderEnum,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SetGuardianFactorsProviderSmsResponseContent]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/put-phone-providers">Update phone configuration</a> endpoint instead.

            <b>Previous functionality</b>: Update the multi-factor authentication SMS provider configuration in your tenant.

        Parameters
        ----------
        provider : GuardianFactorsProviderSmsProviderEnum

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SetGuardianFactorsProviderSmsResponseContent]
            Returns selected SMS provider configuration
        """
        _response = self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/selected-provider",
            method="PUT",
            json={
                "provider": provider,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetGuardianFactorsProviderSmsResponseContent,
                    parse_obj_as(
                        type_=SetGuardianFactorsProviderSmsResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_templates(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[typing.Optional[GetGuardianFactorSmsTemplatesResponseContent]]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/get-factor-phone-templates">Retrieve enrollment and verification phone templates</a> endpoint instead.

            <b>Previous function</b>: Retrieve details of SMS enrollment and verification templates configured for your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Optional[GetGuardianFactorSmsTemplatesResponseContent]]
            SMS enrollment and verification templates successfully retrieved.
        """
        _response = self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/templates",
            method="GET",
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Optional[GetGuardianFactorSmsTemplatesResponseContent],
                    parse_obj_as(
                        type_=typing.Optional[GetGuardianFactorSmsTemplatesResponseContent],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def set_templates(
        self,
        *,
        enrollment_message: str,
        verification_message: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SetGuardianFactorSmsTemplatesResponseContent]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/put-factor-phone-templates">Update enrollment and verification phone templates</a> endpoint instead.

            <b>Previous functionality</b>: Customize the messages sent to complete SMS enrollment and verification.

        Parameters
        ----------
        enrollment_message : str
            Message sent to the user when they are invited to enroll with a phone number.

        verification_message : str
            Message sent to the user when they are prompted to verify their account.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SetGuardianFactorSmsTemplatesResponseContent]
            SMS enrollment and verification templates successfully updated.
        """
        _response = self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/templates",
            method="PUT",
            json={
                "enrollment_message": enrollment_message,
                "verification_message": verification_message,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetGuardianFactorSmsTemplatesResponseContent,
                    parse_obj_as(
                        type_=SetGuardianFactorSmsTemplatesResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawSmsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_twilio_provider(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[GetGuardianFactorsProviderSmsTwilioResponseContent]:
        """
        Retrieve the <a href="https://auth0.com/docs/multifactor-authentication/twilio-configuration">Twilio SMS provider configuration</a> (subscription required).

            A new endpoint is available to retrieve the Twilio configuration related to phone factors (<a href='https://auth0.com/docs/api/management/v2/#!/Guardian/get_twilio'>phone Twilio configuration</a>). It has the same payload as this one. Please use it instead.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetGuardianFactorsProviderSmsTwilioResponseContent]
            Twilio SMS configuration successfully retrieved.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/providers/twilio",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetGuardianFactorsProviderSmsTwilioResponseContent,
                    parse_obj_as(
                        type_=GetGuardianFactorsProviderSmsTwilioResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def set_twilio_provider(
        self,
        *,
        from_: typing.Optional[str] = OMIT,
        messaging_service_sid: typing.Optional[str] = OMIT,
        auth_token: typing.Optional[str] = OMIT,
        sid: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SetGuardianFactorsProviderSmsTwilioResponseContent]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/put-twilio">Update Twilio phone configuration</a> endpoint.

            <b>Previous functionality</b>: Update the Twilio SMS provider configuration.

        Parameters
        ----------
        from_ : typing.Optional[str]
            From number

        messaging_service_sid : typing.Optional[str]
            Copilot SID

        auth_token : typing.Optional[str]
            Twilio Authentication token

        sid : typing.Optional[str]
            Twilio SID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SetGuardianFactorsProviderSmsTwilioResponseContent]
            Twilio SMS configuration successfully updated.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/providers/twilio",
            method="PUT",
            json={
                "from": from_,
                "messaging_service_sid": messaging_service_sid,
                "auth_token": auth_token,
                "sid": sid,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetGuardianFactorsProviderSmsTwilioResponseContent,
                    parse_obj_as(
                        type_=SetGuardianFactorsProviderSmsTwilioResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_selected_provider(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[GetGuardianFactorsProviderSmsResponseContent]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/get-phone-providers">Retrieve phone configuration</a> endpoint instead.

            <b>Previous functionality</b>: Retrieve details for the multi-factor authentication SMS provider configured for your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetGuardianFactorsProviderSmsResponseContent]
            Returns selected SMS provider configuration
        """
        _response = await self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/selected-provider",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetGuardianFactorsProviderSmsResponseContent,
                    parse_obj_as(
                        type_=GetGuardianFactorsProviderSmsResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def set_provider(
        self,
        *,
        provider: GuardianFactorsProviderSmsProviderEnum,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SetGuardianFactorsProviderSmsResponseContent]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/put-phone-providers">Update phone configuration</a> endpoint instead.

            <b>Previous functionality</b>: Update the multi-factor authentication SMS provider configuration in your tenant.

        Parameters
        ----------
        provider : GuardianFactorsProviderSmsProviderEnum

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SetGuardianFactorsProviderSmsResponseContent]
            Returns selected SMS provider configuration
        """
        _response = await self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/selected-provider",
            method="PUT",
            json={
                "provider": provider,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetGuardianFactorsProviderSmsResponseContent,
                    parse_obj_as(
                        type_=SetGuardianFactorsProviderSmsResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_templates(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[typing.Optional[GetGuardianFactorSmsTemplatesResponseContent]]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/get-factor-phone-templates">Retrieve enrollment and verification phone templates</a> endpoint instead.

            <b>Previous function</b>: Retrieve details of SMS enrollment and verification templates configured for your tenant.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Optional[GetGuardianFactorSmsTemplatesResponseContent]]
            SMS enrollment and verification templates successfully retrieved.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/templates",
            method="GET",
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Optional[GetGuardianFactorSmsTemplatesResponseContent],
                    parse_obj_as(
                        type_=typing.Optional[GetGuardianFactorSmsTemplatesResponseContent],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def set_templates(
        self,
        *,
        enrollment_message: str,
        verification_message: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SetGuardianFactorSmsTemplatesResponseContent]:
        """
        This endpoint has been deprecated. To complete this action, use the <a href="https://auth0.com/docs/api/management/v2/guardian/put-factor-phone-templates">Update enrollment and verification phone templates</a> endpoint instead.

            <b>Previous functionality</b>: Customize the messages sent to complete SMS enrollment and verification.

        Parameters
        ----------
        enrollment_message : str
            Message sent to the user when they are invited to enroll with a phone number.

        verification_message : str
            Message sent to the user when they are prompted to verify their account.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SetGuardianFactorSmsTemplatesResponseContent]
            SMS enrollment and verification templates successfully updated.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "guardian/factors/sms/templates",
            method="PUT",
            json={
                "enrollment_message": enrollment_message,
                "verification_message": verification_message,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SetGuardianFactorSmsTemplatesResponseContent,
                    parse_obj_as(
                        type_=SetGuardianFactorSmsTemplatesResponseContent,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
